==> graphql_search_api_solr-1.2.0-beta1.tar.gz: graphql_search_api_solr/src/Plugin/GraphQL/DataProducer/SearchApi/SolrFacetsList.php <==
<?php

namespace Drupal\graphql_search_api_solr\Plugin\GraphQL\DataProducer\SearchApi;

use Drupal\search_api\Query\ResultSet;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Drupal\graphql_search_api_solr\Plugin\GraphQL\Wrappers\FacetsList;

/**
 * Solr Search results count data producer.
 *
 * @DataProducer(
 *   id = "solr_facets_list",
 *   name = @Translation("Solr facets"),
 *   description = @Translation("Display active facets data."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Solr facets")
 *   ),
 *   consumes = {
 *     "result_set" = @ContextDefinition("any",
 *       label = @Translation("Facets"),
 *       required = FALSE,
 *     ),
 *   }
 * )
 */
class SolrFacetsList extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * Executes the Solr search.
   *
   * @param \Drupal\search_api\Query\ResultSet $resultSet
   *   Results set.
   *
   * @return mixed[]
   *   Array FacetsList
   */
  public function resolve(ResultSet $resultSet) {

    $resultSet->getResultCount();

    $facets = [];
    $facetSet = $resultSet->getExtraData('facet_set')->getFacets();
    $index = $resultSet->getQuery()->getIndex();
    // @phpstan-ignore-next-line
    $fieldNames = $index->getServerInstance()
      ->getBackend()->getSolrFieldNames($index);

    foreach ($facetSet as $facetName => $facet) {
      $searchApiFacetName = array_search($facetName, $fieldNames);
      $facets[] = new FacetsList($searchApiFacetName, $facet);
    }

    return $facets;
  }

}

==> graphql_search_api_solr-1.3.1-beta1.tar.gz: graphql_search_api_solr/src/Plugin/GraphQL/DataProducer/SearchApi/SolrFacetsList.php <==
<?php

namespace Drupal\graphql_search_api_solr\Plugin\GraphQL\DataProducer\SearchApi;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\graphql_search_api_solr\Plugin\GraphQL\Wrappers\ResultSet;
use Drupal\graphql\Plugin\GraphQL\DataProducer\DataProducerPluginBase;
use Drupal\graphql_search_api_solr\Plugin\GraphQL\Wrappers\FacetsList;

/**
 * Solr Search results count data producer.
 *
 * @DataProducer(
 *   id = "solr_facets_list",
 *   name = @Translation("Solr facets"),
 *   description = @Translation("Display active facets data."),
 *   produces = @ContextDefinition("any",
 *     label = @Translation("Solr facets")
 *   ),
 *   consumes = {
 *     "result_set" = @ContextDefinition("any",
 *       label = @Translation("Facets"),
 *       required = FALSE,
 *     ),
 *   }
 * )
 */
class SolrFacetsList extends DataProducerPluginBase implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * Executes the Solr search.
   *
   * @param \Drupal\graphql_search_api_solr\Plugin\GraphQL\Wrappers\ResultSet $resultSet
   *   Results set.
   *
   * @return mixed[]
   *   Array FacetsList
   */
  public function resolve(ResultSet $resultSet) {

    $facets = [];
    $results = $resultSet->getResults();
    $langcode = $resultSet->getLangcode();
    $facetSet = $results->getExtraData('facet_set')->getFacets();
    $index = $results->getQuery()->getIndex();
    // @phpstan-ignore-next-line
    $fieldNames = $index->getServerInstance()
      ->getBackend()->getSolrFieldNames($index);

    foreach ($facetSet as $facetName => $facet) {
      $searchApiFacetName = array_search($facetName, $fieldNames);
      $facets[] = new FacetsList($searchApiFacetName, $facet, $langcode);
    }

    return $facets;
  }

}
